/*
 * Copyright 2010,2013 EUROPEAN UNION
 * Licensed under the EUPL, Version 1.1 or - as soon they will be approved by
 * the European Commission - subsequent versions of the EUPL (the "Licence");
 * You may not use this work except in compliance with the Licence.
 * You may obtain a copy of the Licence at:
 *
 * http://ec.europa.eu/idabc/eupl
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the Licence is distributed on an "AS IS" basis,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the Licence for the specific language governing permissions and
 * limitations under the Licence.
 *
 * Date: 28/10/2013
 * Authors: European Commission, Joint Research Centre
 * Daniele Francioli, Emanuela Epure
 * inspire-registry-info@jrc.ec.europa.eu
 *
 * This work was supported by the EU  Interoperability Solutions for
 * European Public Administrations Programme (http://ec.europa.eu/isa)
 * through Action 1.17: Re-usable INSPIRE Reference Platform 
 * (http://ec.europa.eu/isa/actions/01-trusted-information-exchange/1-17action_en.htm).
 */
package eu.europa.ec.re3gistry.jaxbmodel.register;

import eu.europa.ec.re3gistry.jaxbmodel.utilattribute.CodelistAttribute;
import eu.europa.ec.re3gistry.jaxbmodel.utilattribute.DefinitionAttribute;
import eu.europa.ec.re3gistry.jaxbmodel.utilattribute.DescriptionAttribute;
import eu.europa.ec.re3gistry.jaxbmodel.utilattribute.LabelAttribute;
import eu.europa.ec.re3gistry.jaxbmodel.utilattribute.RegisterAttribute;
import java.io.Serializable;
import java.util.Date;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;

@XmlRootElement(name = "item")
@XmlAccessorType(XmlAccessType.FIELD)
public class ItemLabel implements Serializable {

    @XmlElement(name = "uuid")
    private String uuid;
    @XmlElement(name = "label")
    private LabelAttribute label;
    @XmlElement(name = "uri_name")
    private String uri_name;
    @XmlElement(name = "datecreation")
    private Date datecreation;
    @XmlElement(name = "datelastupdate")
    private Date datelastupdate;
    @XmlElement(name = "datetimeaddition")
    private Date datetimeaddition;
    @XmlElement(name = "datetimesupersession")
    private Date datetimesupersession;
    @XmlElement(name = "datetimeretirment")
    private Date datetimeretirment;
    @XmlElement(name = "datetimeinvalidation")
    private Date datetimeinvalidation;
    @XmlElement(name = "definition")
    private DefinitionAttribute definition;
    @XmlElement(name = "description")
    private DescriptionAttribute description;
    @XmlElement(name = "status")
    private StatusLabel status;
    @XmlElement(name = "itemclass")
    private ItemClassLabel itemclass;
    @XmlElement(name = "parent")
    private ParentItemLabel parentItemLabel;
    @XmlElement(name = "predecessor")
    private PredecessorItemLabel predecessorItemLabel;
    @XmlElement(name = "successor")
    private SuccessorItemLabel successorItemLabel;
    @XmlElement(name = "register")
    private RegisterAttribute register;
     @XmlElement(name = "codelist")
    private CodelistAttribute codelist;
    @XmlElement(name = "customattributes")
    private CustomattributeLabelList CustomattributeLabelList;
    @XmlElement(name = "collection")
    private CollectionItemLabel collectionlabelList;
    @XmlElement(name = "children")
    private ItemChildrenLabel children;

    public ItemLabel() {
    }

    public ItemLabel(String uuid) {
        this.uuid = uuid;
    }

    public String getUuid() {
        return uuid;
    }

    public void setUuid(String uuid) {
        this.uuid = uuid;
    }

    public void setLabel(String label, String languageCode) {
        LabelAttribute labelAttribute = new LabelAttribute();
        labelAttribute.setValue(label);
        labelAttribute.setLanguage(languageCode);
        this.label = labelAttribute;
    }

    public LabelAttribute getLabel() {
        return label;
    }

    public String getUri_name() {
        return uri_name;
    }

    public void setUri_name(String uri_name) {
        this.uri_name = uri_name;
    }

    public Date getDatecreation() {
        return datecreation;
    }

    public void setDatecreation(Date datecreation) {
        this.datecreation = datecreation;
    }

    public Date getDatelastupdate() {
        return datelastupdate;
    }

    public void setDatelastupdate(Date datelastupdate) {
        this.datelastupdate = datelastupdate;
    }

    public Date getDatetimeaddition() {
        return datetimeaddition;
    }

    public void setDatetimeaddition(Date datetimeaddition) {
        this.datetimeaddition = datetimeaddition;
    }

    public Date getDatetimesupersession() {
        return datetimesupersession;
    }

    public void setDatetimesupersession(Date datetimesupersession) {
        this.datetimesupersession = datetimesupersession;
    }

    public Date getDatetimeretirment() {
        return datetimeretirment;
    }

    public void setDatetimeretirment(Date datetimeretirment) {
        this.datetimeretirment = datetimeretirment;
    }

    public Date getDatetimeinvalidation() {
        return datetimeinvalidation;
    }

    public void setDatetimeinvalidation(Date datetimeinvalidation) {
        this.datetimeinvalidation = datetimeinvalidation;
    }

    public DefinitionAttribute getDefinition() {
        return definition;
    }

    public void setDefinition(String label, String languageCode) {
        DefinitionAttribute definitionAttribute = new DefinitionAttribute();
        definitionAttribute.setValue(label);
        definitionAttribute.setLanguage(languageCode);
        this.definition = definitionAttribute;
    }

    public DescriptionAttribute getDescription() {
        return description;
    }

    public void setDescription(String label, String languageCode) {
        DescriptionAttribute descriptionAttribute = new DescriptionAttribute();
        descriptionAttribute.setValue(label);
        descriptionAttribute.setLanguage(languageCode);
        this.description = descriptionAttribute;
    }

    public StatusLabel getStatus() {
        return status;
    }

    public void setStatus(StatusLabel status) {
        this.status = status;
    }

    public ItemClassLabel getItemclass() {
        return itemclass;
    }

    public void setItemclass(ItemClassLabel itemclass) {
        this.itemclass = itemclass;
    }

    public void setParent(ParentItemLabel parentItemLabel) {
        this.parentItemLabel = parentItemLabel;
    }

    public void setCollection(CollectionItemLabel collectionlabelList) {
        this.collectionlabelList = collectionlabelList;
    }

    public void setPredecessor(PredecessorItemLabel predecessorItemLabel) {
        this.predecessorItemLabel = predecessorItemLabel;
    }

    public void setSuccessor(SuccessorItemLabel successorItemLabel) {
        this.successorItemLabel = successorItemLabel;
    }

    public ParentItemLabel getParentItemLabel() {
        return parentItemLabel;
    }

    public void setParentItemLabel(ParentItemLabel parentItemLabel) {
        this.parentItemLabel = parentItemLabel;
    }

    public CollectionItemLabel getCollectionlabelList() {
        return collectionlabelList;
    }

    public void setCollectionlabelList(CollectionItemLabel collectionlabelList) {
        this.collectionlabelList = collectionlabelList;
    }

    public PredecessorItemLabel getPredecessorItemLabel() {
        return predecessorItemLabel;
    }

    public void setPredecessorItemLabel(PredecessorItemLabel predecessorItemLabel) {
        this.predecessorItemLabel = predecessorItemLabel;
    }

    public SuccessorItemLabel getSuccessorItemLabel() {
        return successorItemLabel;
    }

    public void setSuccessorItemLabel(SuccessorItemLabel successorItemLabel) {
        this.successorItemLabel = successorItemLabel;
    }

    public eu.europa.ec.re3gistry.jaxbmodel.register.CustomattributeLabelList getCustomattributeLabelList() {
        return CustomattributeLabelList;
    }

    public void setCustomattributeLabelList(eu.europa.ec.re3gistry.jaxbmodel.register.CustomattributeLabelList CustomattributeLabelList) {
        this.CustomattributeLabelList = CustomattributeLabelList;
    }

    public CodelistAttribute getCodelist() {
        return codelist;
    }

    public void setCodelist(CodelistAttribute codelist) {
        this.codelist = codelist;
    }

    public RegisterAttribute getRegister() {
        return register;
    }

    public void setRegister(RegisterAttribute register) {
        this.register = register;
    }

    public ItemChildrenLabel getChildren() {
        return children;
    }

    public void setChildren(ItemChildrenLabel children) {
        this.children = children;
    }
}