/*
* Copyright 2010,2013 EUROPEAN UNION
* Licensed under the EUPL, Version 1.1 or - as soon they will be approved by
* the European Commission - subsequent versions of the EUPL (the "Licence");
* You may not use this work except in compliance with the Licence.
* You may obtain a copy of the Licence at:
*
* http://ec.europa.eu/idabc/eupl
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the Licence is distributed on an "AS IS" basis,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the Licence for the specific language governing permissions and
* limitations under the Licence.
*
* Date: 28/10/2013
* Authors: European Commission, Joint Research Centre
* Daniele Francioli, Emanuela Epure
* inspire-registry-info@jrc.ec.europa.eu
*
* This work was supported by the EU  Interoperability Solutions for
* European Public Administrations Programme (http://ec.europa.eu/isa)
* through Action 1.17: Re-usable INSPIRE Reference Platform 
* (http://ec.europa.eu/isa/actions/01-trusted-information-exchange/1-17action_en.htm).
*/

package eu.europa.ec.re3gistry.model;

import java.io.Serializable;
import java.util.Date;
import javax.persistence.Basic;
import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.Id;
import javax.persistence.JoinColumn;
import javax.persistence.ManyToOne;
import javax.persistence.NamedQueries;
import javax.persistence.NamedQuery;
import javax.persistence.Table;
import javax.persistence.Temporal;
import javax.persistence.TemporalType;
import javax.xml.bind.annotation.XmlRootElement;

@Entity
@Table(name = "register")
@XmlRootElement
@NamedQueries({
    @NamedQuery(name = "Register.findAll", query = "SELECT r FROM Register r"),
    @NamedQuery(name = "Register.findByUuid", query = "SELECT r FROM Register r WHERE r.uuid = :uuid"),
    @NamedQuery(name = "Register.findByBaseUri", query = "SELECT r FROM Register r WHERE r.baseUri = :baseUri"),
    @NamedQuery(name = "Register.findByUriName", query = "SELECT r FROM Register r WHERE r.uriName = :uriName"),
    @NamedQuery(name = "Register.findByDatecreation", query = "SELECT r FROM Register r WHERE r.datecreation = :datecreation"),
    @NamedQuery(name = "Register.findByDatelastupdate", query = "SELECT r FROM Register r WHERE r.datelastupdate = :datelastupdate"),
    @NamedQuery(name = "Register.findByRegisterowner", query = "SELECT r FROM Register r WHERE r.registerowner = :registerowner"),
    @NamedQuery(name = "Register.findByRegistermanager", query = "SELECT r FROM Register r WHERE r.registermanager = :registermanager"),
    @NamedQuery(name = "Register.findByRegistercontrolbody", query = "SELECT r FROM Register r WHERE r.registercontrolbody = :registercontrolbody")})
public class Register implements Serializable {

    private static final long serialVersionUID = 1L;
    @Id
    @Basic(optional = false)
    @Column(name = "uuid")
    private String uuid;
    @Column(name = "base_uri")
    private String baseUri;
    @Basic(optional = false)
    @Column(name = "uri_name")
    private String uriName;
    @Basic(optional = false)
    @Column(name = "datecreation")
    @Temporal(TemporalType.TIMESTAMP)
    private Date datecreation;
    @Column(name = "datelastupdate")
    @Temporal(TemporalType.TIMESTAMP)
    private Date datelastupdate;
    @Column(name = "registerowner")
    private String registerowner;
    @Column(name = "registermanager")
    private String registermanager;
    @Column(name = "registercontrolbody")
    private String registercontrolbody;
    @JoinColumn(name = "registry_id", referencedColumnName = "uuid")
    @ManyToOne
    private Registry registry;

    public Register() {
    }

    public Register(String uuid) {
        this.uuid = uuid;
    }

    public Register(String uuid, String uriName, Date datecreation) {
        this.uuid = uuid;
        this.uriName = uriName;
        this.datecreation = datecreation;
    }

    public String getUuid() {
        return uuid;
    }

    public void setUuid(String uuid) {
        this.uuid = uuid;
    }

    public String getBaseUri() {
        return baseUri;
    }

    public void setBaseUri(String baseUri) {
        this.baseUri = baseUri;
    }

    public String getUriName() {
        return uriName;
    }

    public void setUriName(String uriName) {
        this.uriName = uriName;
    }

    public Date getDatecreation() {
        return datecreation;
    }

    public void setDatecreation(Date datecreation) {
        this.datecreation = datecreation;
    }

    public Date getDatelastupdate() {
        return datelastupdate;
    }

    public void setDatelastupdate(Date datelastupdate) {
        this.datelastupdate = datelastupdate;
    }

    public String getRegisterowner() {
        return registerowner;
    }

    public void setRegisterowner(String registerowner) {
        this.registerowner = registerowner;
    }

    public String getRegistermanager() {
        return registermanager;
    }

    public void setRegistermanager(String registermanager) {
        this.registermanager = registermanager;
    }

    public String getRegistercontrolbody() {
        return registercontrolbody;
    }

    public void setRegistercontrolbody(String registercontrolbody) {
        this.registercontrolbody = registercontrolbody;
    }

    public Registry getRegistry() {
        return registry;
    }

    public void setRegistry(Registry registry) {
        this.registry = registry;
    }

    @Override
    public int hashCode() {
        int hash = 0;
        hash += (uuid != null ? uuid.hashCode() : 0);
        return hash;
    }

    @Override
    public boolean equals(Object object) {
        // TODO: Warning - this method won't work in the case the id fields are not set
        if (!(object instanceof Register)) {
            return false;
        }
        Register other = (Register) object;
        if ((this.uuid == null && other.uuid != null) || (this.uuid != null && !this.uuid.equals(other.uuid))) {
            return false;
        }
        return true;
    }

    @Override
    public String toString() {
        return "eu.europa.ec.re3gistry.model.Register[ uuid=" + uuid + " ]";
    }
}
