/*
 * Copyright 2010,2013 EUROPEAN UNION
 * Licensed under the EUPL, Version 1.1 or - as soon they will be approved by
 * the European Commission - subsequent versions of the EUPL (the "Licence");
 * You may not use this work except in compliance with the Licence.
 * You may obtain a copy of the Licence at:
 *
 * http://ec.europa.eu/idabc/eupl
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the Licence is distributed on an "AS IS" basis,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the Licence for the specific language governing permissions and
 * limitations under the Licence.
 *
 * Date: 28/10/2013
 * Authors: European Commission, Joint Research Centre
 * Daniele Francioli, Emanuela Epure
 * inspire-registry-info@jrc.ec.europa.eu
 *
 * This work was supported by the EU  Interoperability Solutions for
 * European Public Administrations Programme (http://ec.europa.eu/isa)
 * through Action 1.17: Re-usable INSPIRE Reference Platform 
 * (http://ec.europa.eu/isa/actions/01-trusted-information-exchange/1-17action_en.htm).
 */
package eu.europa.ec.re3gistry.re3gistryexport.marshaller;

import eu.europa.ec.re3gistry.constants.EntityNames;
import eu.europa.ec.re3gistry.jaxbmodel.register.CustomattributeLabel;
import eu.europa.ec.re3gistry.jaxbmodel.register.CustomattributeLabelList;
import eu.europa.ec.re3gistry.jaxbmodel.register.ItemChildrenLabel;
import eu.europa.ec.re3gistry.jaxbmodel.register.ItemClassLabel;
import eu.europa.ec.re3gistry.jaxbmodel.register.ItemLabel;
import eu.europa.ec.re3gistry.jaxbmodel.register.ParentItemLabel;
import eu.europa.ec.re3gistry.jaxbmodel.register.PredecessorItemLabel;
import eu.europa.ec.re3gistry.jaxbmodel.register.StatusLabel;
import eu.europa.ec.re3gistry.jaxbmodel.register.SuccessorItemLabel;
import eu.europa.ec.re3gistry.jaxbmodel.utilattribute.CodelistAttribute;
import eu.europa.ec.re3gistry.jaxbmodel.utilattribute.LabelAttribute;
import eu.europa.ec.re3gistry.jaxbmodel.utilattribute.RegisterAttribute;
import eu.europa.ec.re3gistry.jaxbmodel.utilattribute.RegistryAttribute;
import eu.europa.ec.re3gistry.model.Customattribute;
import eu.europa.ec.re3gistry.model.Customattributevalue;
import eu.europa.ec.re3gistry.model.Item;
import eu.europa.ec.re3gistry.model.Itemclass;
import eu.europa.ec.re3gistry.model.Languagecode;
import eu.europa.ec.re3gistry.model.Localization;
import eu.europa.ec.re3gistry.model.Register;
import eu.europa.ec.re3gistry.model.Registry;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;
import javax.persistence.EntityManager;
import javax.persistence.Query;

public class ExportUtility {

    public static void insertItemClass(Itemclass itemClass, EntityManager em, ItemLabel itemLabel, Languagecode localizationLanguage) {
        /**
         * ITEMCLASS
         */
        if (itemClass != null) {
            ItemClassLabel itemclasslabel = new ItemClassLabel();
            itemclasslabel.setUuid(itemClass.getUuid());
            itemclasslabel.setUri_name(itemClass.getUriName());
            /**
             * get from Localization table the row with itemclass and language
             */
            String ITEMCLASS_LOCALIZATION_QUERY = "SELECT loc FROM " + EntityNames.ENTITY_LOCALIZATION + " loc WHERE loc.itemclass = :itemclass AND loc.language = :localizationLanguage";
            Query qicl = em.createQuery(ITEMCLASS_LOCALIZATION_QUERY);
            qicl.setParameter("itemclass", itemClass);
            qicl.setParameter("localizationLanguage", localizationLanguage);
            List<Localization> itemclassLocalizationList = qicl.getResultList();
            if (itemclassLocalizationList.size() == 1) {
                for (Localization localizationitemclass : itemclassLocalizationList) {
                    itemclasslabel.setLabelAttribute(localizationitemclass.getLabel(), localizationitemclass.getLanguage().getIsocode());
                }
            }
            itemLabel.setItemclass(itemclasslabel);
        }
    }

    public static void insertParent(Item itemParent, EntityManager em, ItemLabel itemLabel, Languagecode localizationLanguage) {
        /**
         * PARENT
         */
        if (itemParent != null) {
            ParentItemLabel parentItemLabel = new ParentItemLabel();
            ItemLabel parentLabel = new ItemLabel();
            parentLabel.setUri_name(itemParent.getUriName());

            String PARENTITEM_LOCALIZATION_QUERY = "SELECT loc FROM " + EntityNames.ENTITY_LOCALIZATION + " loc WHERE loc.item = :item AND loc.language = :language";
            Query qipl = em.createQuery(PARENTITEM_LOCALIZATION_QUERY);
            qipl.setParameter("item", itemParent);
            qipl.setParameter("language", localizationLanguage);
            List<Localization> itemparentList = qipl.getResultList();
            if (itemparentList.size() == 1) {
                for (Localization itemparentLocalization : itemparentList) {
                    parentLabel.setLabel(itemparentLocalization.getLabel(), itemparentLocalization.getLanguage().getIsocode());
                }
            }

            ItemClassLabel parentitemclasslabel = new ItemClassLabel();
            Itemclass itemparentitemclass = itemParent.getItemclass();
            parentitemclasslabel.setUuid(itemparentitemclass.getUuid());
            parentitemclasslabel.setUri_name(itemparentitemclass.getUriName());

            String PARENT_LOCALIZATION_QUERY = "SELECT loc FROM " + EntityNames.ENTITY_LOCALIZATION + " loc WHERE loc.itemclass = :itemclass";
            Query qpl = em.createQuery(PARENT_LOCALIZATION_QUERY);
            qpl.setParameter("itemclass", itemparentitemclass);
            List<Localization> itemparentLocalizationList = qpl.getResultList();
            if (itemparentLocalizationList.size() == 1) {
                for (Localization itemparentLocalization : itemparentLocalizationList) {
                    parentitemclasslabel.setLabelAttribute(itemparentLocalization.getLabel(), itemparentLocalization.getLanguage().getIsocode());
                }
            }
            parentLabel.setItemclass(parentitemclasslabel);
            parentItemLabel.setItemlabel(parentLabel);
            itemLabel.setParent(parentItemLabel);
        }
    }

    public static void insertPredecessor(Item itemPredecessor, EntityManager em, ItemLabel itemLabel) {
        /**
         * PREDECESSOR
         */
        if (itemPredecessor != null) {
            PredecessorItemLabel predecessorItemLabel = new PredecessorItemLabel();
            ItemLabel predecessorLabel = new ItemLabel();
            predecessorLabel.setUuid(itemPredecessor.getUuid());
            predecessorLabel.setUri_name(itemPredecessor.getUriName());

            ItemClassLabel predecessoritemclasslabel = new ItemClassLabel();
            Itemclass itempredecessoritemclass = itemPredecessor.getItemclass();
            predecessoritemclasslabel.setUuid(itempredecessoritemclass.getUuid());
            predecessoritemclasslabel.setUri_name(itempredecessoritemclass.getUriName());

            String PREDECESSOR_LOCALIZATION_QUERY = "SELECT loc FROM " + EntityNames.ENTITY_LOCALIZATION + " loc WHERE it.itemclass = :itemclass";
            Query qprl = em.createQuery(PREDECESSOR_LOCALIZATION_QUERY);
            qprl.setParameter("itemclass", itempredecessoritemclass);
            List<Localization> itempredecessorLocalizationList = qprl.getResultList();
            if (itempredecessorLocalizationList.size() == 1) {
                for (Localization itempredecessorLocalization : itempredecessorLocalizationList) {
                    predecessoritemclasslabel.setLabelAttribute(itempredecessorLocalization.getLabel(), itempredecessorLocalization.getLanguage().getIsocode());
                }
            }
            predecessorLabel.setItemclass(predecessoritemclasslabel);
            predecessorItemLabel.setItemlabel(predecessorLabel);
            itemLabel.setPredecessor(predecessorItemLabel);
        }
    }

    public static void insertSuccessor(Item itemSuccessor, EntityManager em, ItemLabel itemLabel) {
        /**
         * SUCCESSOR
         */
        if (itemSuccessor != null) {
            SuccessorItemLabel successorItemLabel = new SuccessorItemLabel();
            ItemLabel successorLabel = new ItemLabel();
            successorLabel.setUuid(itemSuccessor.getUuid());
            successorLabel.setUri_name(itemSuccessor.getUriName());

            ItemClassLabel successoritemclasslabel = new ItemClassLabel();
            Itemclass itemsuccessoritemclass = itemSuccessor.getItemclass();
            successoritemclasslabel.setUuid(itemsuccessoritemclass.getUuid());
            successoritemclasslabel.setUri_name(itemsuccessoritemclass.getUriName());

            String SUCCESSOR_LOCALIZATION_QUERY = "SELECT loc FROM " + EntityNames.ENTITY_LOCALIZATION + " loc WHERE it.itemclass = :itemclass";
            Query qsl = em.createQuery(SUCCESSOR_LOCALIZATION_QUERY);
            qsl.setParameter("itemclass", itemsuccessoritemclass);
            List<Localization> itemsuccessorLocalizationList = qsl.getResultList();
            if (itemsuccessorLocalizationList.size() == 1) {
                for (Localization itemsuccessorLocalization : itemsuccessorLocalizationList) {
                    successoritemclasslabel.setLabelAttribute(itemsuccessorLocalization.getLabel(), itemsuccessorLocalization.getLanguage().getIsocode());
                }
            }
            successorLabel.setItemclass(successoritemclasslabel);
            successorItemLabel.setItemlabel(successorLabel);
            itemLabel.setSuccessor(successorItemLabel);
        }
    }

    public static Customattributevalue insertLocalizationDetail(Localization localizationitem, ItemLabel itemLabel) {
        /**
         * localization details
         */
        String localizationitemUUID = localizationitem.getUuid();
        Item localizationitemItem = localizationitem.getItem();
        Itemclass localizationitemItemClass = localizationitem.getItemclass();
        Languagecode localizationitemLanguage = localizationitem.getLanguage();
        Register localizationitemRegister = localizationitem.getRegister();
        Customattributevalue localizationitemCustomattributevalue = localizationitem.getCustomattributevalue();
        String localizationitemLabel = localizationitem.getLabel();
        String localizationitemDefinition = localizationitem.getDefinition();
        String localizationitemDescription = localizationitem.getDescription();
        Date localizationitemDatecreation = localizationitem.getDatecreation();
        Date localizationitemDatelastmodification = localizationitem.getDatelastupdate();

        itemLabel.setLabel(localizationitemLabel, localizationitemLanguage.getIsocode());
        itemLabel.setDefinition(localizationitemDefinition, localizationitemLanguage.getIsocode());
        itemLabel.setDescription(localizationitemDescription, localizationitemLanguage.getIsocode());
        itemLabel.setDatecreation(localizationitemDatecreation);
        itemLabel.setDatelastupdate(localizationitemDatelastmodification);

        return localizationitemCustomattributevalue;
    }

    public static void insertCustomAttribute(EntityManager em, Item item, ItemLabel itemLabel, Languagecode language) {
        CustomattributeLabelList customattributeLabelList = new CustomattributeLabelList();
        ArrayList<CustomattributeLabel> customattributeLabelArray = new ArrayList<CustomattributeLabel>();

        /**
         * get the itemClass
         */
        Itemclass itemclass = item.getItemclass();

        String ITEMCLASS_CUSTOMATTRIBUTE_QUERY = "SELECT ca FROM " + EntityNames.ENTITY_CUSTOMATTRIBUTE + " ca WHERE ca.itemclass = :itemclass";
        Query iccaq = em.createQuery(ITEMCLASS_CUSTOMATTRIBUTE_QUERY);
        iccaq.setParameter("itemclass", itemclass);

        List<Customattribute> customattributeList = iccaq.getResultList();
        for (Customattribute customattribute : customattributeList) {
            String customattributeUUID = customattribute.getUuid();
            boolean customattributeRequired = customattribute.getRequired();
            String customattributeName = customattribute.getName();
            boolean customattributeMultivalue = customattribute.getMultivalue();
            boolean customattributeIsforeignkKey = customattribute.getIsforeignkey();
            Date customattributeDatecreation = customattribute.getDatecreation();
            Date customattributeDatelastupdate = customattribute.getDatelastupdate();
            boolean customattributeCoded = customattribute.getCoded();

            String CUSTOMATTRIBUTEVALUE_QUERY = "SELECT cav FROM " + EntityNames.ENTITY_CUSTOMATTRIBUTEVALUE + " cav WHERE cav.item = :item AND cav.customattribute = :customattribute";
            Query cavq = em.createQuery(CUSTOMATTRIBUTEVALUE_QUERY);
            cavq.setParameter("item", item);
            cavq.setParameter("customattribute", customattribute);

            List<Customattributevalue> customattributevalueList = cavq.getResultList();
            for (Customattributevalue customattributevalue : customattributevalueList) {

                String LOCALIZATIONS_QUERY = "SELECT loc FROM " + EntityNames.ENTITY_LOCALIZATION + " loc WHERE loc.customattributevalue = :customattributevalue AND loc.language = :language";
                Query locq = em.createQuery(LOCALIZATIONS_QUERY);
                locq.setParameter("customattributevalue", customattributevalue);
                locq.setParameter("language", language);

                List<Localization> localizationList = locq.getResultList();
                for (Localization localization : localizationList) {
                    String localizationUUID = localization.getUuid();
                    Item localizationItem = localization.getItem();
                    Itemclass localizationItemClass = localization.getItemclass();
                    Languagecode localizationLanguage = localization.getLanguage();
                    Register localizationRegister = localization.getRegister();
                    Customattributevalue localizationCustomattributevalue = localization.getCustomattributevalue();
                    String localizationLabel = localization.getLabel();
                    String localizationDefinition = localization.getDefinition();
                    String localizationDescription = localization.getDescription();
                    Date localizationDatecreation = localization.getDatecreation();
                    Date localizationDatelastupdate = localization.getDatelastupdate();

                    CustomattributeLabel customattributeLabel = new CustomattributeLabel();
                    customattributeLabel.setName(customattributeName);
                    customattributeLabel.setRequired(customattributeRequired);
                    customattributeLabel.setMultivalue(customattributeMultivalue);
                    customattributeLabel.setIsforeignKey(customattributeIsforeignkKey);
                    customattributeLabel.setCoded(customattributeCoded);
                    customattributeLabel.setDatecreation(customattributeDatecreation);
                    customattributeLabel.setDatelastupdate(customattributeDatelastupdate);
                    customattributeLabel.setLabel(localizationLabel, localizationLanguage.getIsocode());

                    customattributeLabelArray.add(customattributeLabel);
                }
            }
        }
        customattributeLabelList.setCustomattributeLabel(customattributeLabelArray);
        itemLabel.setCustomattributeLabelList(customattributeLabelList);
    }

    public static void insertChildren(EntityManager em, Item item, ItemLabel itemLabel, Languagecode localizationLanguageItem, String localizationLabel) {
        String ITEMPARENT_QUERY = "SELECT i FROM " + EntityNames.ENTITY_ITEM + " i WHERE i.parent = :parent";
        Query ipq = em.createQuery(ITEMPARENT_QUERY);
        ipq.setParameter("parent", item);
        List<Item> itemList = ipq.getResultList();

        ItemChildrenLabel itemChildrenLabel = new ItemChildrenLabel();
        ArrayList<ItemLabel> arrayItemLabel = new ArrayList<ItemLabel>();
        for (Item childitem : itemList) {

            String CHILDITEM_LOCALIZATION_QUERY = "SELECT loc FROM " + EntityNames.ENTITY_LOCALIZATION + " loc WHERE loc.item = :childitem  AND loc.language = :language";
            Query qrlc = em.createQuery(CHILDITEM_LOCALIZATION_QUERY);
            qrlc.setParameter("childitem", childitem);
            qrlc.setParameter("language", localizationLanguageItem);

            List<Localization> childitemLocalizationList = qrlc.getResultList();
            if (!childitemLocalizationList.isEmpty() && childitemLocalizationList.size() == 1) {
                String childitemlanguageIsocode = childitemLocalizationList.get(0).getLanguage().getIsocode();

                ItemLabel childItemLabel = new ItemLabel();

                childItemLabel.setUuid(childitem.getUuid());
                childItemLabel.setUri_name(childitem.getUriName());
                childItemLabel.setDatecreation(childitem.getDatecreation());
                childItemLabel.setDatelastupdate(childitem.getDatelastupdate());
                childItemLabel.setDatetimeaddition(childitem.getDatetimeaddition());
                childItemLabel.setDatetimesupersession(childitem.getDatetimesupersession());
                childItemLabel.setDatetimeretirment(childitem.getDatetimeretirment());
                childItemLabel.setDatetimeinvalidation(childitem.getDatetimeinvalidation());

                StatusLabel statusLabel = new StatusLabel();
                statusLabel.setUuid(childitem.getStatus().getUuid());
                statusLabel.setUri(childitem.getStatus().getUri());

                String STATUS_LOCALIZATION_QUERY = "SELECT loc FROM " + EntityNames.ENTITY_LOCALIZATION + " loc WHERE loc.language = :language  AND loc.status = :status";
                Query qstatus = em.createQuery(STATUS_LOCALIZATION_QUERY);
                qstatus.setParameter("language", localizationLanguageItem);
                qstatus.setParameter("status", childitem.getStatus());
                List<Localization> statusLocalizationList = qstatus.getResultList();
                for (Localization localization : statusLocalizationList) {
                    statusLabel.setLabelAttribute(localization.getLabel(), childitemlanguageIsocode);
                }

                childItemLabel.setStatus(statusLabel);
                childItemLabel.setLabel(childitemLocalizationList.get(0).getLabel(), childitemlanguageIsocode);
                childItemLabel.setDescription(childitemLocalizationList.get(0).getDescription(), childitemlanguageIsocode);
                childItemLabel.setDefinition(childitemLocalizationList.get(0).getDefinition(), childitemlanguageIsocode);

                /**
                 * set codelist
                 */
                String codeListUriName = item.getUriName();
                CodelistAttribute codelistAttribute = new CodelistAttribute();
                codelistAttribute.setUri_name(codeListUriName);
                LabelAttribute labelAttribute = new LabelAttribute();
                labelAttribute.setValue(localizationLabel);
                labelAttribute.setLanguage(localizationLanguageItem.getIsocode());
                codelistAttribute.setLabel(labelAttribute);
                childItemLabel.setCodelist(codelistAttribute);

                Register register = item.getRegister();

                String registerBaseUri = register.getBaseUri();
                String registerUriName = register.getUriName();

                RegisterAttribute registerAttribute = new RegisterAttribute();
                registerAttribute.setBase_uri(registerBaseUri);
                registerAttribute.setUri_name(registerUriName);

                String REGISTER_LOCALIZATION_QUERY = "SELECT loc FROM " + EntityNames.ENTITY_LOCALIZATION + " loc WHERE loc.register = :register";
                Query qrel = em.createQuery(REGISTER_LOCALIZATION_QUERY);
                qrel.setParameter("register", item.getRegister());

                List<Localization> localizationRegisterList = qrel.getResultList();
                for (Localization registerlocalization : localizationRegisterList) {
                    if (registerlocalization.getLanguage().equals(localizationLanguageItem)) {
                        LabelAttribute registerlabelAttribute = new LabelAttribute();
                        registerlabelAttribute.setValue(registerlocalization.getLabel());
                        registerlabelAttribute.setLanguage(registerlocalization.getLanguage().getIsocode());
                        registerAttribute.setLabel(registerlabelAttribute);
                    }
                }

                RegistryAttribute registryAttribute = new RegistryAttribute();
                Registry registry = register.getRegistry();
                registryAttribute.setBase_uri(registry.getBaseUri());
                registryAttribute.setUri_name(registry.getUriName());

                String REGISTER_LOCALIZATION = "SELECT loc FROM " + EntityNames.ENTITY_LOCALIZATION + " loc WHERE loc.registry = :registry";
                Query qr = em.createQuery(REGISTER_LOCALIZATION);
                qr.setParameter("registry", registry);

                List<Localization> registerLocalization = qr.getResultList();
                for (Localization registerLocalizationItem : registerLocalization) {
                    String registerLocalizationItemLabel = registerLocalizationItem.getLabel();
                    Languagecode registerLocalizationItemLanguage = registerLocalizationItem.getLanguage();

                    LabelAttribute registerlabelAttribute = new LabelAttribute();
                    registerlabelAttribute.setValue(registerLocalizationItemLabel);
                    registerlabelAttribute.setLanguage(registerLocalizationItemLanguage.getIsocode());

                    registryAttribute.setLabel(registerlabelAttribute);
                }

                registerAttribute.setRegistry(registryAttribute);
                /**
                 *
                 */
                childItemLabel.setRegister(registerAttribute);

                /**
                 * ITEMCLASS
                 */
                ExportUtility.insertItemClass(childitem.getItemclass(), em, childItemLabel, childitemLocalizationList.get(0).getLanguage());

                /**
                 * PARENT
                 */
                if (childitem.getParent() != null) {
                    ExportUtility.insertParent(childitem.getParent(), em, childItemLabel, childitemLocalizationList.get(0).getLanguage());
                }

                /**
                 * PREDECESSOR
                 */
                ExportUtility.insertPredecessor(childitem.getPredecessor(), em, childItemLabel);

                /**
                 * SUCCESSOR
                 */
                ExportUtility.insertSuccessor(childitem.getSuccessor(), em, childItemLabel);

                /**
                 * CUSTOM ATTRIBUTE
                 */
                ExportUtility.insertCustomAttribute(em, childitem, childItemLabel, childitemLocalizationList.get(0).getLanguage());

//                ExportUtility.insertChildren(em, childitem, childItemLabel, localizationLanguageItem, localizationLabel);

                arrayItemLabel.add(childItemLabel);
            }
            itemChildrenLabel.setItemlabel(arrayItemLabel);
            itemLabel.setChildren(itemChildrenLabel);
        }
    }
}
