/*
* Copyright 2010,2013 EUROPEAN UNION
* Licensed under the EUPL, Version 1.1 or - as soon they will be approved by
* the European Commission - subsequent versions of the EUPL (the "Licence");
* You may not use this work except in compliance with the Licence.
* You may obtain a copy of the Licence at:
*
* http://ec.europa.eu/idabc/eupl
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the Licence is distributed on an "AS IS" basis,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the Licence for the specific language governing permissions and
* limitations under the Licence.
*
* Date: 28/10/2013
* Authors: European Commission, Joint Research Centre
* Daniele Francioli, Emanuela Epure
* inspire-registry-info@jrc.ec.europa.eu
*
* This work was supported by the EU  Interoperability Solutions for
* European Public Administrations Programme (http://ec.europa.eu/isa)
* through Action 1.17: Re-usable INSPIRE Reference Platform 
* (http://ec.europa.eu/isa/actions/01-trusted-information-exchange/1-17action_en.htm).
*/

package eu.europa.ec.re3gistry.re3gistryexport.servlet;

import eu.europa.ec.re3gistry.model.Registry;
import eu.europa.ec.re3gistry.re3gistryexport.manager.Configuration;
import eu.europa.ec.re3gistry.re3gistryexport.marshaller.RegisterExport;
import java.io.File;
import java.io.IOException;
import java.util.List;
import javax.persistence.EntityManager;
import javax.persistence.EntityManagerFactory;
import javax.persistence.Persistence;
import javax.persistence.Query;
import javax.servlet.ServletException;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

public class ServletExportDatabase extends HttpServlet {

    private static final long serialVersionUID = 1L;
    private static final String KEY_PERSISTENCE_UNIT_NAME = "persistence.unit.name";
    private static final String KEY_EXPORT_MAINFOLDER_CUSTOM = "export.mainfolder.custom";
    private static final String KEY_EXPORT_MAINFOLDER_NAME = "export.mainfolder.name";
    private static final String KEY_EXPORT_STANDARD_FOLDER_NAME = "export.folder.standard";
    private static final String KEY_EXPORT_FOLDERIDENTIFIER = "export.context.folderidentifier";
    private String exportMainfolderCustom;
    private String exportMainfolderName;
    private String exportStandardFolder;
    private String contextFolderIdentifier;
    private String folderExport;
    private String persistenceUnitName;
    private String folderSeparator = System.getProperty("file.separator");

    protected void doPost(HttpServletRequest request, HttpServletResponse response) throws ServletException, IOException {
        try {
            /**
             * Getting properties
             */
            exportMainfolderCustom = Configuration.getInstance().getProperty(KEY_EXPORT_MAINFOLDER_CUSTOM, null);
            exportMainfolderName = Configuration.getInstance().getProperty(KEY_EXPORT_MAINFOLDER_NAME, "export");
            exportStandardFolder = Configuration.getInstance().getProperty(KEY_EXPORT_STANDARD_FOLDER_NAME, "standard");
            contextFolderIdentifier = Configuration.getInstance().getProperty(KEY_EXPORT_FOLDERIDENTIFIER, "WEB-INF");
            persistenceUnitName = Configuration.getInstance().getProperty(KEY_PERSISTENCE_UNIT_NAME, "Re3gistry");

            /**
             * Get the right directory for the job
             */
            if (exportMainfolderCustom != null && !exportMainfolderCustom.trim().equals("")) {
                /**
                 * If it is setted the custom export mainfolder, it creates the
                 * folders name (from properties)
                 */
                folderExport = exportMainfolderCustom + folderSeparator + exportMainfolderName + folderSeparator + exportStandardFolder;
            } else {
                /**
                 * Else get the servlet context path and then creates the
                 * folders name (from properties)
                 */
                String relativePath = getServletContext().getRealPath(contextFolderIdentifier);
                folderExport = relativePath.replaceAll(contextFolderIdentifier, "") + exportMainfolderName + folderSeparator + exportStandardFolder;
            }

            /**
             * Checking if all the folder exist
             */
            File f = new File(folderExport);
            if (!f.isDirectory()) {
                f.mkdirs();
            }

            /**
             * Preparing persistence manager
             */
            EntityManagerFactory emf = Persistence.createEntityManagerFactory(persistenceUnitName);
            EntityManager em = emf.createEntityManager();
            em.getTransaction().begin();

            /**
             * Getting all registers
             */
            Query q = em.createNamedQuery("Registry.findAll");
            List<Registry> registryList = q.getResultList();
            new RegisterExport(folderExport, em, registryList);

            /**
             * Closing transaction
             */
            em.getTransaction().commit();
            em.close();
            emf.close();

            response.sendRedirect("index.jsp");
        } catch (Exception ex) {
            System.out.println("An error occurred while parsing the web form fields. " + ex.getMessage());
        }
    }
}