/*
 * Copyright 2010,2013 EUROPEAN UNION
 * Licensed under the EUPL, Version 1.1 or - as soon they will be approved by
 * the European Commission - subsequent versions of the EUPL (the "Licence");
 * You may not use this work except in compliance with the Licence.
 * You may obtain a copy of the Licence at:
 *
 * http://ec.europa.eu/idabc/eupl
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the Licence is distributed on an "AS IS" basis,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the Licence for the specific language governing permissions and
 * limitations under the Licence.
 *
 * Date: 28/10/2013
 * Authors: European Commission, Joint Research Centre
 * Daniele Francioli, Emanuela Epure
 * inspire-registry-info@jrc.ec.europa.eu
 *
 * This work was supported by the EU  Interoperability Solutions for
 * European Public Administrations Programme (http://ec.europa.eu/isa)
 * through Action 1.17: Re-usable INSPIRE Reference Platform 
 * (http://ec.europa.eu/isa/actions/01-trusted-information-exchange/1-17action_en.htm).
 */
package eu.europa.ec.re3gistry.re3gistryexport.servlet;

import eu.europa.ec.re3gistry.model.Language_fix;
import eu.europa.ec.re3gistry.model.Languagecode;
import eu.europa.ec.re3gistry.model.Localization;
import eu.europa.ec.re3gistry.re3gistryexport.manager.Configuration;
import java.io.IOException;
import java.util.HashMap;
import java.util.List;
import javax.persistence.EntityManager;
import javax.persistence.EntityManagerFactory;
import javax.persistence.Persistence;
import javax.persistence.Query;
import javax.servlet.ServletException;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

public class ServletLanguageFix extends HttpServlet {

    private static final String KEY_PERSISTENCE_UNIT_NAME = "persistence.unit.name";
    private String persistenceUnitName;

    protected void doPost(HttpServletRequest request, HttpServletResponse response) throws ServletException, IOException {
        try {

            persistenceUnitName = Configuration.getInstance().getProperty(KEY_PERSISTENCE_UNIT_NAME, "Re3gistry");

            EntityManagerFactory emf = Persistence.createEntityManagerFactory(persistenceUnitName);
            EntityManager em = emf.createEntityManager();
            em.getTransaction().begin();

            Query q = em.createNamedQuery("Language_fix.findAll");
            List<Language_fix> languagefixRes = q.getResultList();

            HashMap <String,String> language_fix_map = new HashMap<String, String>();
            for (int i = 0; i < languagefixRes.size(); i++) {
                Language_fix tmp = (Language_fix)languagefixRes.get(i);
                language_fix_map.put(tmp.getLanguageId(), tmp.getText());
            }
            
            q = em.createNamedQuery("Languagecode.findByUuid");
            q.setParameter("uuid", "1");
            Languagecode lc = (Languagecode)q.getSingleResult();
            
            q = em.createNativeQuery("select * from localization l join item i on i.uuid=l.item_id where "
                                + "(i.itemclass_id='3' or i.itemclass_id='1')"
                                + "and l.language_id='1' and l.description is not null", Localization.class);
            
            List<Localization> localizationEnglishList = q.getResultList();
                     
            for (int i = 0; i < localizationEnglishList.size(); i++) {
                Localization enloc = (Localization)localizationEnglishList.get(i);
                
                Query q1 = em.createQuery("SELECT l FROM Localization l WHERE l.item = :item and l.language <> :language",Localization.class);              
                q1.setParameter("item", enloc.getItem());
                q1.setParameter("language", lc);
                List <Localization> listToBeUpdated = q1.getResultList();
                
                for(int j=0; j<listToBeUpdated.size(); j++){
                    
                    Localization tmploc = (Localization) listToBeUpdated.get(j);
                    
                    
                    String infoText = language_fix_map.get(tmploc.getLanguage().getUuid());
                    tmploc.setDescription(infoText +" "+ enloc.getDescription());
                    
                    em.persist(tmploc);
                }
                
            }
            
            em.getTransaction().commit();
            
        } catch (Exception e) {
            System.out.println("Error:");
            e.printStackTrace();
        }
    }
}