<?xml version="1.0"?>

<!--  Copyright 2010,2013 EUROPEAN UNION
  Licensed under the EUPL, Version 1.1 or - as soon they will be approved by
  the European Commission - subsequent versions of the EUPL (the "Licence");
  You may not use this work except in compliance with the Licence.
  You may obtain a copy of the Licence at:
 
  http://ec.europa.eu/idabc/eupl
 
  Unless required by applicable law or agreed to in writing, software
  distributed under the Licence is distributed on an "AS IS" basis,
  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
  See the Licence for the specific language governing permissions and
  limitations under the Licence.
 
  Date: 14/06/2013
  Authors: European Commission, Joint Research Centre
  Daniele Francioli, Emanuela Epure
  inspire-registry-info@jrc.ec.europa.eu
 
This work was supported by the EU  Interoperability Solutions for
European Public Administrations Programme (http://ec.europa.eu/isa)
through Action 1.17: Re-usable INSPIRE Reference Platform 
(http://ec.europa.eu/isa/actions/01-trusted-information-exchange/1-17action_en.htm).-->


<xsl:stylesheet version="2.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
    
    <!--Properties-->
    <xsl:output method="xml" version="1.0" encoding="UTF-8" indent="yes"/>
    
    <!--Common variables-->
    <xsl:variable name="base_uri" select="item/register/base_uri"/>
    <xsl:variable name="register_uri_name" select="item/register/uri_name"/>
    <xsl:variable name="item_uri_name" select="item/uri_name"/>
    <xsl:variable name="author_name" select="'INSPIRE Registry team'"/>
    <xsl:variable name="author_email" select="'inspire-registry-info@jrc.ec.europa.eu'"/>
    <xsl:variable name="author_uri" select="'http://inspire.ec.europa.eu/registry'"/>
    
    <xsl:variable name='newline'>&lt;br/&gt;</xsl:variable>
    
    <!--Stylesheet-->
    <xsl:template match="item">
        <feed xmlns="http://www.w3.org/2005/Atom">
            <xsl:attribute name="xml:lang">
                <xsl:value-of select="label/@language"/>
            </xsl:attribute>
            
            <!--Atom id (item uri)-->
            <xsl:element name="id">
                <xsl:value-of select="$base_uri"/>
                <xsl:text>/</xsl:text>
                <xsl:value-of select="$register_uri_name"/>
                <xsl:text>/</xsl:text>
                <xsl:value-of select="uri_name"/>		
            </xsl:element>
            
            <!--Atom title (item label)-->
            <xsl:element name="title">
                <xsl:value-of select="label"/>		
            </xsl:element>
            
            <!--Atom author-->            
            <xsl:element name="author">
                <xsl:element name="name">
                    <xsl:value-of select="$author_name"/>
                </xsl:element>
                <xsl:element name="email">
                    <xsl:value-of select="$author_email"/>
                </xsl:element>
                <xsl:element name="uri">
                    <xsl:value-of select="$author_uri"/>
                </xsl:element>	
            </xsl:element>
            
            <!--Atom subtitle (item definition)-->
            <xsl:if test="definition != ''">
                <xsl:element name="subtitle">
                    <xsl:variable name="tmp" select="definition"/>
                    <xsl:variable name="newtext" select="replace($tmp,'\\n',$newline)"/>
                    <xsl:value-of select="$newtext" disable-output-escaping="yes"/>	
                </xsl:element>
            </xsl:if>
            
            <!--Atom link to itself -->
            <xsl:element name="link">
                <xsl:attribute name="href">
                    <xsl:value-of select="$base_uri"/>
                    <xsl:text>/</xsl:text>
                    <xsl:value-of select="$register_uri_name"/>
                    <xsl:text>/</xsl:text>
                    <xsl:value-of select="uri_name"/>
                </xsl:attribute>                
                <xsl:attribute name="rel">
                    <xsl:text>self</xsl:text>
                </xsl:attribute>
            </xsl:element>
            
            <!-- Reference to the register -->
            <xsl:element name="link">
                <xsl:attribute name="href">
                    <xsl:value-of select="$base_uri"/>
                    <xsl:text>/</xsl:text>
                    <xsl:value-of select="$register_uri_name"/>
                </xsl:attribute>                
                <xsl:attribute name="rel">
                    <xsl:text>up</xsl:text>
                </xsl:attribute>
            </xsl:element>
            
            <!--Atom category -->
            <xsl:element name="category">
                <xsl:attribute name="term">
                    <xsl:value-of select="itemclass/uri_name"/>
                </xsl:attribute>
            </xsl:element>
            
            <!--Atom updated-->
            <xsl:element name="updated">           
                <xsl:choose>
                    <xsl:when test="datelastupdate != ''">
                        <xsl:value-of select="datelastupdate"/>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:value-of select="datecreation"/>
                    </xsl:otherwise>
                </xsl:choose>
            </xsl:element>
           
        </feed>
    </xsl:template>
</xsl:stylesheet>