<?xml version="1.0" encoding="UTF-8"?>

<!--  Copyright 2010,2013 EUROPEAN UNION
  Licensed under the EUPL, Version 1.1 or - as soon they will be approved by
  the European Commission - subsequent versions of the EUPL (the "Licence");
  You may not use this work except in compliance with the Licence.
  You may obtain a copy of the Licence at:
 
  http://ec.europa.eu/idabc/eupl
 
  Unless required by applicable law or agreed to in writing, software
  distributed under the Licence is distributed on an "AS IS" basis,
  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
  See the Licence for the specific language governing permissions and
  limitations under the Licence.
 
  Date: 14/06/2013
  Authors: European Commission, Joint Research Centre
  Daniele Francioli, Emanuela Epure
  inspire-registry-info@jrc.ec.europa.eu
 
This work was supported by the EU  Interoperability Solutions for
European Public Administrations Programme (http://ec.europa.eu/isa)
through Action 1.17: Re-usable INSPIRE Reference Platform 
(http://ec.europa.eu/isa/actions/01-trusted-information-exchange/1-17action_en.htm).-->


<xsl:stylesheet version="2.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"> 
    
    <xsl:include href="dxbox.xsl" />
    <xsl:include href="top_right.xsl" />
    <xsl:include href="footer.xsl" />
    <xsl:include href="res.xsl" />
    
    <!--Properties-->
    <xsl:output method="html" encoding="UTF-8" indent="yes"/>
    
    <!--Common variables-->
    <xsl:param name="base_db_export_path" />
    <xsl:variable name="register_base_uri" select="register/base_uri"/>
    <xsl:variable name="base_res_uri" select="register/base_uri" />
    <xsl:variable name="register_uri_name" select="register/uri_name"/>
    <xsl:variable name="registry_base_uri" select="register/registry/base_uri"/>
    <xsl:variable name="registry_uri_name" select="register/registry/uri_name"/>
    <xsl:variable name="registry_label" select="register/registry/label"/>
    <xsl:variable name="languagecode" select="register/label/@language"/>
        
    <xsl:variable name="languagefile" select="document(concat('../gui-languages/',$languagecode,'.xml'))" />
    
    <xsl:variable name='newline'>&lt;br/&gt;</xsl:variable>
    
    <!--Stylesheet-->
    <xsl:template match="/">
        <xsl:text disable-output-escaping='yes'>&lt;!DOCTYPE html&gt;</xsl:text>   
        <html>
            <xsl:attribute name="lang">
                <xsl:value-of select="$languagecode" />
            </xsl:attribute>
            <head>
                <meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
                <title>
                    <xsl:value-of select="register/label" />
                </title>
                <xsl:call-template name="res">
                    <xsl:with-param name="base_res_uri" select="$base_res_uri"/>
                </xsl:call-template>
            </head>
            
            <body>
                <header>
                    <div id="topright">
                        <xsl:call-template name="top_right"/>
                    </div>
                    <div id="breadctxt">
                        <a href="http://ec.europa.eu/index_en.htm">
                            <xsl:value-of select="$languagefile/guilanguage/item[@key='ec']"/>
                        </a>
                        <xsl:text disable-output-escaping="yes">&amp;</xsl:text>nbsp;
                        <xsl:text disable-output-escaping="yes">&amp;</xsl:text>gt;
                        <a href="http://inspire.jrc.ec.europa.eu/">
                            <xsl:value-of select="$languagefile/guilanguage/item[@key='inspire']"/>
                        </a>
                        <xsl:text disable-output-escaping="yes">&amp;</xsl:text>nbsp;
                        <xsl:text disable-output-escaping="yes">&amp;</xsl:text>gt;
                        <a>
                            <xsl:attribute name="href" >
                                <xsl:value-of select="$registry_base_uri"/>
                                <xsl:text>/</xsl:text>
                                <xsl:value-of select="$registry_uri_name"/>
                            </xsl:attribute>    
                            <xsl:value-of select="$registry_label"/>
                        </a>
                        <xsl:text disable-output-escaping="yes">&amp;</xsl:text>nbsp;
                        <xsl:text disable-output-escaping="yes">&amp;</xsl:text>gt;
                        <span>
                            <xsl:value-of select="register/label" />
                        </span>
                    </div>
                </header>
                
                <article class="exp">
                    <xsl:apply-templates select="register"/>
                </article>
                
                <footer>
                    <xsl:call-template name="footer"/>
                </footer>
                
                <xsl:call-template name="dxbox"/>
                
            </body>
        </html>
    </xsl:template>

    <xsl:template match="register">
     
        <h2>
            <xsl:value-of select="label" />
        </h2>
        
        <p>
            <span>
                <xsl:value-of select="$languagefile/guilanguage/item[@key='id']"/>:</span> 
            <a>
                <xsl:attribute name="href">
                    <xsl:value-of select="$register_base_uri"/>
                    <xsl:text>/</xsl:text>
                    <xsl:value-of select="$register_uri_name"/>            
                </xsl:attribute>    
                <xsl:value-of select="$register_base_uri"/>
                <xsl:text>/</xsl:text>
                <xsl:value-of select="$register_uri_name"/>
            </a>
        </p>
        
        <p>
            <span>
                <xsl:value-of select="$languagefile/guilanguage/item[@key='language']"/>:</span> 
            <strong>
                <xsl:value-of select="label/@language"/>
            </strong>
        </p>
        
        <xsl:if test="label != ''">
            <p>
                <span>
                    <xsl:value-of select="$languagefile/guilanguage/item[@key='label']"/>:</span> 
                <strong>
                    <xsl:value-of select="label" />
                </strong>
            </p>
        </xsl:if>
        
        <xsl:if test="owner != ''">
            <p>
                <span>
                    <xsl:value-of select="$languagefile/guilanguage/item[@key='owner']"/>:</span> 
                <strong>
                    <xsl:value-of select="$languagefile/guilanguage/item[@key='ec']"/>
                </strong>
            </p>
        </xsl:if>
        
        <xsl:if test="manager != ''">
            <p>
                <span>
                    <xsl:value-of select="$languagefile/guilanguage/item[@key='register-manager']"/>:</span> 
                <strong>
                    <xsl:value-of select="$languagefile/guilanguage/item[@key='ec']"/>
                    <xsl:text>, </xsl:text>
                    <xsl:value-of select="$languagefile/guilanguage/item[@key='jrc']"/>
                </strong>
            </p>
        </xsl:if>        

        <xsl:if test="controlbody != ''">
            <p>
                <span>
                    <xsl:value-of select="$languagefile/guilanguage/item[@key='control-body']"/>:</span> 
                <strong>
                    <xsl:value-of select="$languagefile/guilanguage/item[@key='mig']"/>
                </strong>
            </p>
        </xsl:if>
        
        <xsl:if test="definition != ''">
            <p>
                <span class="csm">
                    <xsl:value-of select="$languagefile/guilanguage/item[@key='content-summary']"/>:</span>
            </p>
            <div class="dcsm">
                <xsl:variable name="tmp" select="definition"/>
                <xsl:variable name="newtext" select="replace($tmp,'\\n',$newline)"/>
                <xsl:value-of select="$newtext" disable-output-escaping="yes"/>
            </div>
        </xsl:if>
        
        <xsl:if test="description != ''">
            <p>
                <span class="csm">
                    <xsl:value-of select="$languagefile/guilanguage/item[@key='description']"/>:</span>
            </p>    
            <div class="dcsm">
                <xsl:variable name="tmp" select="description"/>
                <xsl:variable name="newtext" select="replace($tmp,'\\n',$newline)"/>
                <xsl:value-of select="$newtext" disable-output-escaping="yes"/>
            </div>            
        </xsl:if>
        
        <p>
            <span>
                <xsl:value-of select="$languagefile/guilanguage/item[@key='registry']"/>:</span> 
            <a>
                <xsl:attribute name="href">
                    <xsl:value-of select="registry/base_uri"/>
                    <xsl:text>/</xsl:text>
                    <xsl:value-of select="registry/uri_name"/>
                </xsl:attribute>
                <xsl:value-of select="registry/label"/>
            </a>
        </p>
        
        <p>
            <span>
                <xsl:value-of select="$languagefile/guilanguage/item[@key='other-formats']"/>:</span>
            <a>
                <xsl:attribute name="href">
                    <xsl:value-of select="$registry_base_uri"/>
                    <xsl:text>/</xsl:text>
                    <xsl:value-of select="$register_uri_name"/>
                    <xsl:text>/</xsl:text>
                    <xsl:value-of select="$register_uri_name"/>
                    <xsl:text>.</xsl:text>
                    <xsl:value-of select="$languagecode"/>
                    <xsl:text>.xml</xsl:text>       
                </xsl:attribute>
                <xsl:attribute name="class">
                    <xsl:text>fmt xml</xsl:text>                      
                </xsl:attribute>
                <xsl:value-of select="'XML'"/>
            </a>
            <a>
                <xsl:attribute name="href">
                    <xsl:value-of select="$registry_base_uri"/>
                    <xsl:text>/</xsl:text>
                    <xsl:value-of select="$register_uri_name"/>
                    <xsl:text>/</xsl:text>
                    <xsl:value-of select="$register_uri_name"/> 
                    <xsl:text>.</xsl:text>
                    <xsl:value-of select="$languagecode"/>
                    <xsl:text>.json</xsl:text>       
                </xsl:attribute>
                <xsl:attribute name="class">
                    <xsl:text>fmt json</xsl:text>                      
                </xsl:attribute>
                <xsl:value-of select="'JSON'"/>
            </a>
            <a>
                <xsl:attribute name="href">
                    <xsl:value-of select="$registry_base_uri"/>
                    <xsl:text>/</xsl:text>
                    <xsl:value-of select="$register_uri_name"/>
                    <xsl:text>/</xsl:text>
                    <xsl:value-of select="$register_uri_name"/>
                    <xsl:text>.</xsl:text>
                    <xsl:value-of select="$languagecode"/>
                    <xsl:text>.atom</xsl:text>       
                </xsl:attribute>
                <xsl:attribute name="class">
                    <xsl:text>fmt atom</xsl:text>                      
                </xsl:attribute>
                <xsl:value-of select="'Atom'"/>
            </a>
        </p>
        
        <!--Table-->
        <xsl:if test="items != ''">
            <br/>
            <h3>
                <xsl:value-of select="$languagefile/guilanguage/item[@key='code-list']"/>
            </h3>     
                    
            <div class="tb_cont">
                
                <xsl:choose>
                    <xsl:when test="count(//items/item/parent) != 0">
                        <table id = "tbl"> 
                            <thead>
                                <tr>
                                    <th>
                                        <xsl:value-of select="$languagefile/guilanguage/item[@key='label']"/>
                                    </th>
                                    <th>
                                        <xsl:value-of select="$languagefile/guilanguage/item[@key='theme']"/>
                                    </th>
                                    <th>
                                        <xsl:value-of select="$languagefile/guilanguage/item[@key='application-schema']"/>
                                    </th>
                                    <th>
                                        <xsl:value-of select="$languagefile/guilanguage/item[@key='status']"/>
                                    </th>
                                    <th>
                                        <xsl:value-of select="$languagefile/guilanguage/item[@key='parent']"/>
                                    </th>
                                </tr>  
                            </thead>          
                            <xsl:for-each select="items/item">                
                                <tr>
                                    <xsl:variable name="uri_name" select="uri_name"/>
                                    <xsl:variable name="id" select="concat($register_base_uri, '/', $register_uri_name,'/',$uri_name)"/>
                                    <td>
                                        <a>
                                            <xsl:attribute name="href" select="$id"/>
                                            <xsl:value-of select="label"/>
                                        </a>
                                    </td>
                            
                                    <xsl:variable name="applicationschema" select="customattributes/customattribute[name/text()='ApplicationSchema']/label"></xsl:variable>
                                    <xsl:variable name="applicationschemaName" select="substring-after(substring-after(
                                    substring-after(
                                    substring-after
                                    ($applicationschema, '/'),'/'),'/'),'/')">
                                    </xsl:variable>  
                                    <xsl:variable name="language" select="label/@language"/>
                                    <xsl:variable name="applicationschemaFileName" select="concat($register_base_uri, '/applicationschema/', $applicationschemaName,'/',$applicationschemaName,'.en.xml')"/>
                                    <xsl:variable name="applicationschema_label" select="document($applicationschemaFileName)/applicationschema/label"/>
                                    <xsl:variable name="theme_url" select="document($applicationschemaFileName)/applicationschema/theme/@id"/>
                                    <!--<xsl:variable name="theme_label" select="document($applicationschemaFileName)/applicationschema/theme/label"/>-->
                            
                                    <xsl:variable name="themeName" select="substring-after(
                                    substring-after(
                                    substring-after(
                                    substring-after
                                    ($theme_url, '/'),'/'),'/'),'/')">
                                    </xsl:variable>  
                                    <xsl:variable name="theme_xml_file_to_read" select="concat($theme_url, '/',$themeName,'.',$language,'.xml')"/>   
                                    <xsl:variable name="theme_label" select="document($theme_xml_file_to_read)/theme/label"/>
                   
                                    <td>
                                        <a>
                                            <xsl:attribute name="href" select="$theme_url"/>
                                            <xsl:value-of select="$theme_label"/>
                                        </a>
                                    </td>   
                            
                                    <td>
                                        <a>
                                            <xsl:attribute name="href" select="$applicationschema"/>
                                            <xsl:value-of select="$applicationschema_label"/>
                                        </a>
                                    </td>
                              
                                    <td>
                                        <a>
                                            <xsl:attribute name="href" select="status/uri"/>
                                            <xsl:value-of select="status/label"/>
                                        </a>
                                    </td>
                                    
                                    <td>
                                        <xsl:variable name="parent_uri_name" select="parent/item/uri_name"/>
                                        <xsl:variable name="parent_id" select="concat($register_base_uri, '/', $register_uri_name,'/',$parent_uri_name)"/>
                                        <a>
                                            <xsl:attribute name="href" select="$parent_id"/>
                                            <xsl:value-of select="parent/item/label"/>
                                        </a>
                                    </td>
                                </tr>
                            </xsl:for-each>
                        </table>
                    </xsl:when>
                    <xsl:otherwise>
                        <table id = "tbl"> 
                            <thead>
                                <tr>
                                    <th>
                                        <xsl:value-of select="$languagefile/guilanguage/item[@key='label']"/>
                                    </th>
                                    <th>
                                        <xsl:value-of select="$languagefile/guilanguage/item[@key='theme']"/>
                                    </th>
                                    <th>
                                        <xsl:value-of select="$languagefile/guilanguage/item[@key='application-schema']"/>
                                    </th>
                                    <th>
                                        <xsl:value-of select="$languagefile/guilanguage/item[@key='status']"/>
                                    </th>
                                </tr>  
                            </thead>          
                            <xsl:for-each select="items/item">                
                                <tr>
                                    <xsl:variable name="uri_name" select="uri_name"/>
                                    <xsl:variable name="id" select="concat($register_base_uri, '/', $register_uri_name,'/',$uri_name)"/>
                                    <td>
                                        <a>
                                            <xsl:attribute name="href" select="$id"/>
                                            <xsl:value-of select="label"/>
                                        </a>
                                    </td>
                            
                                    <xsl:variable name="applicationschema" select="customattributes/customattribute[name/text()='ApplicationSchema']/label"></xsl:variable>
                                    <xsl:variable name="applicationschemaName" select="substring-after(substring-after(
                                    substring-after(
                                    substring-after
                                    ($applicationschema, '/'),'/'),'/'),'/')">
                                    </xsl:variable>  
                                    <xsl:variable name="language" select="label/@language"/>
                                    <xsl:variable name="applicationschemaFileName" select="concat($register_base_uri, '/applicationschema/', $applicationschemaName,'/',$applicationschemaName,'.en.xml')"/>
                                    <xsl:variable name="applicationschema_label" select="document($applicationschemaFileName)/applicationschema/label"/>
                                    <xsl:variable name="theme_url" select="document($applicationschemaFileName)/applicationschema/theme/@id"/>
                                    <!--<xsl:variable name="theme_label" select="document($applicationschemaFileName)/applicationschema/theme/label"/>-->
                            
                                    <xsl:variable name="themeName" select="substring-after(
                                    substring-after(
                                    substring-after(
                                    substring-after
                                    ($theme_url, '/'),'/'),'/'),'/')">
                                    </xsl:variable>  
                                    <xsl:variable name="theme_xml_file_to_read" select="concat($theme_url, '/',$themeName,'.',$language,'.xml')"/>   
                                    <xsl:variable name="theme_label" select="document($theme_xml_file_to_read)/theme/label"/>
                   
                                    <td>
                                        <a>
                                            <xsl:attribute name="href" select="$theme_url"/>
                                            <xsl:value-of select="$theme_label"/>
                                        </a>
                                    </td>   
                            
                                    <td>
                                        <a>
                                            <xsl:attribute name="href" select="$applicationschema"/>
                                            <xsl:value-of select="$applicationschema_label"/>
                                        </a>
                                    </td>
                              
                                    <td>
                                        <a>
                                            <xsl:attribute name="href" select="status/uri"/>
                                            <xsl:value-of select="status/label"/>
                                        </a>
                                    </td>
                                </tr>
                            </xsl:for-each>
                        </table>
                    </xsl:otherwise>
                </xsl:choose>
                
            </div>
        </xsl:if>
        
    </xsl:template>
</xsl:stylesheet>