<?xml version="1.0" encoding="UTF-8"?>
<!--  Copyright 2010,2013 EUROPEAN UNION
  Licensed under the EUPL, Version 1.1 or - as soon they will be approved by
  the European Commission - subsequent versions of the EUPL (the "Licence");
  You may not use this work except in compliance with the Licence.
  You may obtain a copy of the Licence at:
 
  http://ec.europa.eu/idabc/eupl
 
  Unless required by applicable law or agreed to in writing, software
  distributed under the Licence is distributed on an "AS IS" basis,
  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
  See the Licence for the specific language governing permissions and
  limitations under the Licence.
 
  Date: 14/06/2013
  Authors: European Commission, Joint Research Centre
  Daniele Francioli, Emanuela Epure
  inspire-registry-info@jrc.ec.europa.eu
 
This work was supported by the EU  Interoperability Solutions for
European Public Administrations Programme (http://ec.europa.eu/isa)
through Action 1.17: Re-usable INSPIRE Reference Platform 
(http://ec.europa.eu/isa/actions/01-trusted-information-exchange/1-17action_en.htm).-->

<xsl:stylesheet version="2.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
    
    <xsl:include href="../res.xsl" />
    
    <xsl:output method="html"/>
    
    <xsl:variable name="lang" select="guilanguage/@languagecode" />
    <xsl:variable name="languagecode" select="guilanguage/@languagecode" />
    
    <xsl:template match="/">  
        
        <xsl:text disable-output-escaping='yes'>&lt;!DOCTYPE html&gt;</xsl:text>
        <html>
            <xsl:attribute name="lang">
                <xsl:value-of select="$lang" />
            </xsl:attribute>
            <head>
                <meta http-equiv="Content-Type" content="text/html; charset=UTF-8" />
                <title>INSPIRE registry</title>
                <xsl:call-template name="resmin"/>
            </head>
            <body>
                <div id="about-dialog" title="INSPIRE registry">                  
                    
                    <h2>About - INSPIRE Registry</h2>
                    <p>The data, metadata and services exchanged in the INSPIRE infrastructure include a number of properties whose values are taken from well-defined lists of items. Examples for such items include INSPIRE themes, code lists, application schemas or discovery services. To improve interoperability, it will be beneficial to refer to these values through unique identifiers rather than textual descriptions. Registers provide a means to assign identifiers to items and their labels, definitions, descriptions (in different languages) as well as potentially other item-specific properties. The INSPIRE registry provides a central access point to a number of centrally managed INSPIRE registers. The content of these registers are based on the INSPIRE Directive, Implementing Rules and Technical Guidelines.</p>
                    <br/>
                    <p>Currently, the INSPIRE registry contains the following registers:</p>
                    <ul>
                        <li>INSPIRE Theme register: Names, definitions (from the INSPIRE Directive) and descriptions (based on the Data Specifications Technical Guidelines)</li>
                        <li>INSPIRE Code List register: Labels, definitions, descriptions and extensibility of the code lists and their values, as included in the Implementing Rules on interoperability of spatial data sets and services. The code list register does not yet include references to external vocabularies or the extensions proposed in the Data Specifications Technical Guidelines. These will be added at a later stage.</li>
                        <li>INSPIRE Application Schema register: Labels and definitions of the INSPIRE application schemas.</li>
                    </ul>
                    <p>In future releases, it is planned to add further registers, e.g. an updated version of the Feature Concept Dictionary and the INSPIRE glossary.</p>
                    <br/>

                    <h3>Accessing the registry</h3>
                    <p>All the resources available in the INSPIRE registry can be accessed in a number of formats, currently:</p>
                    <ul>
                        <li>HTML - html</li>
                        <li>XML - xml</li>
                        <li>ATOM - atom</li>
                        <li>JSON - json</li>
                    </ul>
                    <br/>
                    <p>The content of the registers is available in the following languages. Since the translations are taken from the official translations of the INSPIRE legal acts, some properties of an item (those that are based on the content of the Technical Guidelines) are currently only available in English.</p>
                    <ul>
                        <li>Bulgarian - bg</li>
                        <li>Czech - cs </li>
                        <li>Danish - da </li>
                        <li>German - de </li>
                        <li>Greek - el </li>
                        <li>Spanish - es </li>
                        <li>Estonian - et </li>
                        <li>Finnish - fi </li>
                        <li>French - fr </li>
                        <li>Hungarian - hu </li>
                        <li>Italian - it </li>
                        <li>Lithuanian - lt </li>
                        <li>Latvian - lv </li>
                        <li>Maltese - mt </li>
                        <li>Dutch - nl </li>
                        <li>Polish - pl </li>
                        <li>Portuguese - pt</li> 
                        <li>Romanian - ro </li>
                        <li>Slovak - sk </li>
                        <li>Slovenian - sl </li>
                        <li>Swedish - sv</li>
                    </ul>
                    <br/>
                    <p>The GUI translations are provisional and may be improved in future releases.</p>
                    
                    <br/>
                    <p>By default, the register content is provided based on the preferred language and format indicated in the request (e.g. the HTTP GET request issued by the browser). If you want to access a register item in a particular format or language you can use one of the following approaches.</p>

                    <h3>Directly accessing an item</h3>
                    <p>To directly access an item in a specific language and format, use the following naming convention:</p> 
                    <p>
                        <strong>http://inspire.ec.europa.eu/{register}/[{item identifier}]/{item identifier}.{ language code}.{format}</strong>
                    </p>
                    <p>where the "language code" and "format" are the codes in bold in the previous lists.</p>
                    <br/>
                    <p>Examples:</p>
                    <ul>
                        <li>http://inspire.ec.europa.eu/codelist/codelist.en.xml</li>
                        <li>http://inspire.ec.europa.eu/codelist/BreakLineTypeValue/BreakLineTypeValue.en.html</li>
                        <li>http://inspire.ec.europa.eu/codelist/GeometryMethodValue/byAdministrator/byAdministrator.en.xml</li>
                        <li>http://inspire.ec.europa.eu/applicationschema/applicationschema.en.atom</li>
                        <li>http://inspire.ec.europa.eu/applicationschema/ad/ad.en.atom</li>
                        <li>http://inspire.ec.europa.eu/applicationschema/ad/ad.en.json</li>
                    </ul>
                    <br/>
                    <h3>Accessing an item using content negotiation.</h3>
                    <p>To access an item using content negotiation, add to the HTTP request the format and language header. Some examples are listed below:</p> 
                    <p>Examples:</p>
                    <ul>
                        <li>xml, english:
                            <ul>
                                <li>URL: http://inspire.ec.europa.eu/codelist</li>
                                <li>HTTP header: <br/>Accept-Language: en<br/> Accept: application/xml</li> 
                            </ul>
                        </li>
                        <li>
                            atom, english: 
                            <ul>
                                <li>URL: http://inspire.ec.europa.eu/applicationschema/ad</li>
                                <li>HTTP header:<br/> 
                                    Accept-Language: en<br/> 
                                    Accept: application/atom+xml
                                </li> 
                            </ul>
                        </li>
                    </ul>
                    <br/>
                    <p>Below you can find all the supported format and their relative http header</p>
                    <ul>
                        <li>ATOM: application/atom+xml</li> 
                        <li>HTML: text/html </li> 
                        <li>XML: application/xml </li> 
                        <li>JSON: application/json </li> 
                    </ul>
                    <h3>Acknowledgements</h3>
                    <p>The INSPIRE registry is based on the Re3gistry software, which is being developed by the Are3NA project  as part of the Interoperability Solutions for European Public Administrations (ISA) Programme [2] . ARe3NA  aims at establishing a Reusable INSPIRE Reference Platform, which is identifying and developing common components for the successful implementation of the INSPIRE Directive. To further address these interoperability issues and provide support to the Member States, the platform will provide guidance, collaboration, sharing of best practices and approaches and a reference implementation of common components.</p>
                </div>
            </body>
        </html>
        
    </xsl:template>
</xsl:stylesheet>
