<?xml version="1.0" encoding="UTF-8"?>
<!--  Copyright 2010,2013 EUROPEAN UNION
  Licensed under the EUPL, Version 1.1 or - as soon they will be approved by
  the European Commission - subsequent versions of the EUPL (the "Licence");
  You may not use this work except in compliance with the Licence.
  You may obtain a copy of the Licence at:
 
  http://ec.europa.eu/idabc/eupl
 
  Unless required by applicable law or agreed to in writing, software
  distributed under the Licence is distributed on an "AS IS" basis,
  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
  See the Licence for the specific language governing permissions and
  limitations under the Licence.
 
  Date: 14/06/2013
  Authors: European Commission, Joint Research Centre
  Daniele Francioli, Emanuela Epure
  inspire-registry-info@jrc.ec.europa.eu
 
This work was supported by the EU  Interoperability Solutions for
European Public Administrations Programme (http://ec.europa.eu/isa)
through Action 1.17: Re-usable INSPIRE Reference Platform 
(http://ec.europa.eu/isa/actions/01-trusted-information-exchange/1-17action_en.htm).-->

<xsl:stylesheet version="2.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
    
    <xsl:include href="../res.xsl" />
    
    <xsl:output method="html"/>
    
    <xsl:variable name="lang" select="guilanguage/@languagecode" />
    <xsl:variable name="languagecode" select="guilanguage/@languagecode" />
    
    <xsl:template match="/">        
        <xsl:text disable-output-escaping='yes'>&lt;!DOCTYPE html&gt;</xsl:text>
        <html>
            <xsl:attribute name="lang">
                <xsl:value-of select="$lang" />
            </xsl:attribute>
            <head>
                <meta http-equiv="Content-Type" content="text/html; charset=UTF-8" />
                <title>
                    <xsl:value-of select="guilanguage/item[@key='inspire-registry']" />
                </title>
                <xsl:call-template name="resmin"/>
            </head>

            <body>
                <div id="about-dialog" title="INSPIRE registry"> 
                    
                    <h2>
                        INSPIRE Registry
                    </h2>

                    <h4>The content of this registry is available in different formats and languages.</h4>
                    <p>The formats currently available are:</p>
                    <ul>
                        <li>HTML - <strong>html</strong></li>
                        <li>XML - <strong>xml</strong></li>
                        <li>ATOM - <strong>atom</strong></li>
                        <li>JSON - <strong>json</strong></li>
                    </ul>
                    <p>The languages currently available are:</p>
                    <ul>
                        <li>English - <strong>en</strong></li>
                        <li>Bulgarian - <strong>bg</strong></li>
                        <li>Czech - <strong>cs</strong></li>
                        <li>Croatian - <strong>hr</strong></li>
                        <li>Danish - <strong>da</strong></li>
                        <li>German - <strong>de</strong></li>
                        <li>Greek - <strong>el</strong></li>
                        <li>Spanish - <strong>es</strong></li>
                        <li>Estonian - <strong>et</strong></li>
                        <li>Finnish - <strong>fi</strong></li>
                        <li>French - <strong>fr</strong></li>
                        <li>Hungarian - <strong>hu</strong></li>
                        <li>Italian - <strong>it</strong></li>
                        <li>Lithuanian - <strong>lt</strong></li>
                        <li>Latvian - <strong>lv</strong></li>
                        <li>Maltese - <strong>mt</strong></li>
                        <li>Dutch - <strong>nl</strong></li>
                        <li>Polish - <strong>pl</strong></li>
                        <li>Portuguese - <strong>pt</strong></li>
                        <li>Romanian - <strong>ro</strong></li>
                        <li>Slovak - <strong>sk</strong></li>
                        <li>Slovenian - <strong>sl</strong></li>
                        <li>Swedish - <strong>sv</strong></li>
                    </ul>
                    
                    <p>Please note that some of the content is not yet available in all languages. Where this is the case, the English translation will be provided.</p>
                    <p>The GUI translations are provisional and may be improved in future releases.</p>                  
                    
                    <br/>
                    <h4>If you want to get the resource in a particular format or language you can:</h4>
                    <ul>
                        <li>Use the language selector in the web interface;</li>
                        <li>Directly call the resources using its name;</li>
                        <li>Call the resource using the content negotiation approach.</li>
                    </ul>
                    
                    <br/>
                    <h4>Direct call</h4>
                    <p>If you want to directly call the resources using its name you have to follow the naming convention explained in the example below:</p>
                    <p><strong>http://inspire.ec.europa.eu/{register}/[{resource-name}]/{resource-name}.{resource-language-code}.{resource-format}</strong></p>
                    <p>You can find the specific "resource-language-code" and "resource-format-code" in the list above (the codes are highlighted in bold).</p>
                    <p>Examples:</p>
                    <ul>
                        <li>
                            <a target="_blank" href="http://inspire.ec.europa.eu/codelist/codelist.en.xml">http://inspire.ec.europa.eu/codelist/<strong>codelist.en.xml</strong></a>
                        </li>
                        <li>
                            <a target="_blank" href="http://inspire.ec.europa.eu/codelist/GeometryMethodValue/GeometryMethodValue.en.xml">http://inspire.ec.europa.eu/codelist/BreakLineTypeValue/<strong>BreakLineTypeValue.en.html</strong></a>
                        </li>
                        <li>
                            <a target="_blank" href="http://inspire.ec.europa.eu/codelist/GeometryMethodValue/byAdministrator/byAdministrator.en.xml">http://inspire.ec.europa.eu/codelist/GeometryMethodValue/byAdministrator/<strong>byAdministrator.en.xml</strong></a>
                        </li>
                        <li>
                            <a target="_blank" href="http://inspire.ec.europa.eu/applicationschema/applicationschema.en.atom">http://inspire.ec.europa.eu/applicationschema/<strong>applicationschema.en.atom</strong></a>
                        </li>
                        <li>
                            <a target="_blank" href="http://inspire.ec.europa.eu/applicationschema/ad/ad.en.atom">http://inspire.ec.europa.eu/applicationschema/ad/<strong>ad.en.atom</strong></a>
                        </li>
                        <li>
                            <a target="_blank" href="http://inspire.ec.europa.eu/applicationschema/ad/ad.en.json">http://inspire.ec.europa.eu/applicationschema/ad/<strong>ad.en.json</strong></a>
                        </li>
                    </ul>
                    
                    <br/>
                    <h4>Content negotiation</h4>
                    <p>If you want to call the resources using the content negotiation approach, you have add to the HTTP request the format and language header. Some example are listed below:</p>
                    <p>Examples:</p>
                    <ul>
                        <li>xml, english: 	 
                            <ul>
                                <li>URL:
                                    <br/>
                                    <strong>http://inspire.ec.europa.eu/codelist</strong>
                                </li>
                                <li>HTTP header:
                                    <br/>
                                    <strong>Accept-Language: en
                                        <br/>Accept: application/xml
                                    </strong>
                                </li>
                            </ul>
                        </li>
                        <li>atom, english:
                            <ul>
                                <li>URL:
                                    <br/>
                                    <strong>http://inspire.ec.europa.eu/applicationschema/ad</strong>
                                </li>
                                <li>HTTP header:
                                    <br/>
                                    <strong>Accept-Language: en
                                        <br/>Accept: application/atom+xml
                                    </strong>
                                </li>
                            </ul>
                        </li>
                    </ul>
                    <br/>
                    <h4>Below you can find all the supported format and their relative http header:</h4>
                    <ul>
                        <li>ATOM: application/atom+xml</li>
                        <li>HTML: text/html</li>
                        <li>XML: application/xml</li>
                        <li>JSON: application/json</li>
                    </ul>
                </div>
            </body>
        </html>        
    </xsl:template>
</xsl:stylesheet>
