<?xml version="1.0" encoding="UTF-8"?>

<!--  Copyright 2010,2013 EUROPEAN UNION
  Licensed under the EUPL, Version 1.1 or - as soon they will be approved by
  the European Commission - subsequent versions of the EUPL (the "Licence");
  You may not use this work except in compliance with the Licence.
  You may obtain a copy of the Licence at:
 
  http://ec.europa.eu/idabc/eupl
 
  Unless required by applicable law or agreed to in writing, software
  distributed under the Licence is distributed on an "AS IS" basis,
  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
  See the Licence for the specific language governing permissions and
  limitations under the Licence.
 
  Date: 14/06/2013
  Authors: European Commission, Joint Research Centre
  Daniele Francioli, Emanuela Epure
  inspire-registry-info@jrc.ec.europa.eu
 
This work was supported by the EU  Interoperability Solutions for
European Public Administrations Programme (http://ec.europa.eu/isa)
through Action 1.17: Re-usable INSPIRE Reference Platform 
(http://ec.europa.eu/isa/actions/01-trusted-information-exchange/1-17action_en.htm).-->


<xsl:stylesheet version="2.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"> 
    
    <xsl:include href="../dxbox.xsl" />
    <xsl:include href="../top_right.xsl" />
    <xsl:include href="../footer.xsl" />
    <xsl:include href="../res.xsl" />
    
    <xsl:output method="html"/>
    
    <xsl:variable name="languagefile" select="document(concat('../../gui-languages/',$languagecode,'.xml'))" />
    <xsl:variable name="languagecode" select="guilanguage/@languagecode"/>
        
    <xsl:template match="/">  
        <xsl:text disable-output-escaping='yes'>&lt;!DOCTYPE html&gt;</xsl:text>
        <html>
            <xsl:attribute name="lang">
                <xsl:value-of select="$languagecode" />
            </xsl:attribute>
            <head>
                <meta http-equiv="Content-Type" content="text/html; charset=UTF-8" />
                <title>
                    <xsl:value-of select="guilanguage/item[@key='inspire-registry']" />
                </title>
                <xsl:call-template name="res"/>
            </head>

            <body>
                <header>
                    <div id="topright">
                        <xsl:call-template name="top_right"/>
                    </div>
                    <div id="breadctxt">
                        <a href="http://ec.europa.eu/index_en.htm"><xsl:value-of select="guilanguage/item[@key='ec']"/></a>
                        <xsl:text disable-output-escaping="yes">&amp;</xsl:text>nbsp;
                        <xsl:text disable-output-escaping="yes">&amp;</xsl:text>gt;
                        <a href="http://inspire.ec.europa.eu/"><xsl:value-of select="guilanguage/item[@key='inspire']"/></a>
                        <xsl:text disable-output-escaping="yes">&amp;</xsl:text>nbsp;
                        <xsl:text disable-output-escaping="yes">&amp;</xsl:text>gt;
                        <a href="http://inspire.ec.europa.eu/registry"><xsl:value-of select="guilanguage/item[@key='inspire-registry']"/></a>
                        <xsl:text disable-output-escaping="yes">&amp;</xsl:text>nbsp;
                        <xsl:text disable-output-escaping="yes">&amp;</xsl:text>gt;
                        <span>Re3gistry</span>
                    </div>
                </header>
                <article class="exp">
                    <h2>Re3gistry</h2>
                    
                    <p>
                        <span>Version:</span>
                        <strong>0.2</strong>
                    </p>

                    <p>The Re3gistry is a tool used to manage the data contained in the registry. It is made up of an import procedure, an export procedure and a web service.</p>
                    <p>The import procedure loads the data provided (in .csv format) into the database.</p>
                    <p>The export procedure prepares the data saved in the database in order to be ready for the web service.</p>
                    <p>The web service has a RESTful interface to access the data. You can access different formats and languages using content negotiation or directly calling the desired file.</p>
                    <p>For more information go to the Re3gistry software home page(<a href="https://joinup.ec.europa.eu/software/re3gistry/home">https://joinup.ec.europa.eu/software/re3gistry/home</a>).</p>
		 		 
                    <br/>
                    <br/>
                    <br/>
                    <a target="_blank" href="http://ec.europa.eu/isa/actions/01-trusted-information-exchange/1-17action_en.htm">
                        <img src="../res/img/main/isa.png" alt="Interoperability Solutions for European Public Administrations" title="Interoperability Solutions for European Public Administrations"/>
                    </a>
                    <xsl:text disable-output-escaping="yes">&amp;</xsl:text>nbsp;<xsl:text disable-output-escaping="yes">&amp;</xsl:text>nbsp;
                    <a target="_blank" href="http://joinup.ec.europa.eu/">
                        <img src="../res/img/main/joinup.png" alt="Share and reuse interoperability solutions for public administrations" title="Share and reuse interoperability solutions for public administrations"/>
                    </a>	 
                    <xsl:text disable-output-escaping="yes">&amp;</xsl:text>nbsp;<xsl:text disable-output-escaping="yes">&amp;</xsl:text>nbsp;
                    <a target="_blank" href="https://joinup.ec.europa.eu/community/are3na/description">
                        <img src="../res/img/main/arena.png" alt="A Reusable INSPIRE Reference Platform" title="A Reusable INSPIRE Reference Platform"/>
                    </a>
		 
                </article>
                <footer>
                    <xsl:call-template name="footer"/>
                </footer>
                
                <xsl:call-template name="dxbox"/>
            </body>
        </html>
        
    </xsl:template>
</xsl:stylesheet>