/*
 * Copyright 2010,2013 EUROPEAN UNION
 * Licensed under the EUPL, Version 1.1 or - as soon they will be approved by
 * the European Commission - subsequent versions of the EUPL (the "Licence");
 * You may not use this work except in compliance with the Licence.
 * You may obtain a copy of the Licence at:
 *
 * http://ec.europa.eu/idabc/eupl
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the Licence is distributed on an "AS IS" basis,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the Licence for the specific language governing permissions and
 * limitations under the Licence.
 *
 * Date: 28/10/2013
 * Authors: European Commission, Joint Research Centre
 * Daniele Francioli, Emanuela Epure
 * inspire-registry-info@jrc.ec.europa.eu
 *
 * This work was supported by the EU  Interoperability Solutions for
 * European Public Administrations Programme (http://ec.europa.eu/isa)
 * through Action 1.17: Re-usable INSPIRE Reference Platform 
 * (http://ec.europa.eu/isa/actions/01-trusted-information-exchange/1-17action_en.htm).
 */
package eu.europa.ec.re3gistry.re3gistryimport.servlet;

import eu.europa.ec.re3gistry.re3gistryimport.manager.Configuration;
import eu.europa.ec.re3gistry.re3gistryimport.manager.ImportMgr;
import java.io.IOException;
import java.io.File;
import java.io.FileOutputStream;
import java.util.List;
import java.util.zip.ZipEntry;
import java.util.zip.ZipInputStream;
import javax.servlet.RequestDispatcher;
import javax.servlet.ServletException;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import org.apache.commons.fileupload.FileItem;
import org.apache.commons.fileupload.FileUploadException;
import org.apache.commons.fileupload.disk.DiskFileItemFactory;
import org.apache.commons.fileupload.servlet.ServletFileUpload;
import org.apache.log4j.Logger;

public class ImportEngine extends HttpServlet {

    private static final long serialVersionUID = 1L;
    private static final String TEMP_FOLDER = "import.temp.folder";
    private static final String VALUE_RERIDECT_TARGET = "/index.jsp";
    private static Logger log = Logger.getLogger(ImportEngine.class);
    private ImportMgr imgr;
    private String tempFolder = null;

    @Override
    protected void doPost(HttpServletRequest request, HttpServletResponse response) throws ServletException, IOException {

        log.info("####");
        log.info("#### IMPORT PROCEDURE ####");

        //Reading the temp folder from the webapp.properties file
        tempFolder = Configuration.getInstance().getProperty(TEMP_FOLDER, null);

        if (tempFolder == null) {
            log.error("No temp folder configured; please check your configuration file.");
        } else {
            try {
                log.info("Temp folder setted: " + tempFolder);

                //Istantiating the import manager
                imgr = new ImportMgr();

                //Getting the zip file uploaded from the web form
                List<FileItem> fl = new ServletFileUpload(new DiskFileItemFactory()).parseRequest(request);
                FileItem importFile = null;
                for (FileItem item : fl) {
                    if (!item.isFormField()) {
                        importFile = item;
                    }
                }

                //Checking if the import file is not null
                if (importFile != null && importFile.getSize() != 0) {
                    log.info("Unzipping files");
                    if (!this.unzipFile(tempFolder, importFile)) {
                        throw new Exception("An error occurred while unzipping the file.");
                    }

                    //Starting import
                    log.info("Starting items import;");
                    imgr.startImport(tempFolder);

                } else {
                    log.info("Warning: the import file was not found or the file was empty; could not execute the request.");
                }
            } catch (FileUploadException e) {
                log.error("There was an error while uploading files.", e);
            } catch (Exception e) {
                log.error("There was a generic error while executing the request.", e);
            }
        }

        log.info("#### IMPORT PROCEDURE FINISHED ####");
        log.info("####");
        log.info("");

        RequestDispatcher rd;
        rd = getServletContext().getRequestDispatcher(VALUE_RERIDECT_TARGET);
        rd.forward(request, response);
    }

    private boolean unzipFile(String tempDir, FileItem importFile) {
        byte[] buffer = new byte[1024];

        try {
            //Checking the temp folder
            File folder = new File(tempDir);
            if (!folder.exists()) {
                folder.mkdir();
            }

            ZipInputStream zis = new ZipInputStream(importFile.getInputStream());
            ZipEntry ze = zis.getNextEntry();

            while (ze != null) {
                String fileName = ze.getName();
                File newFile = new File(tempDir + File.separator + fileName);

                if (ze.isDirectory()) {
                    if (!newFile.exists()) {
                        newFile.mkdir();
                    }
                } else {
                    log.info("Unzipping file: " + newFile.getAbsoluteFile());

                    FileOutputStream fos = new FileOutputStream(newFile);
                    int len;
                    while ((len = zis.read(buffer)) > 0) {
                        fos.write(buffer, 0, len);
                    }

                    fos.close();
                }
                ze = zis.getNextEntry();
            }

            zis.closeEntry();
            zis.close();

            return true;
        } catch (Exception e) {
            log.error("An error occurred while unzipping the file.", e);
            return false;
        }
    }
}